<?php

namespace Litecms\BusCategory\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\BusCategory\Http\Requests\BusCategoriesRequest;
use Litecms\BusCategory\Interfaces\BusCategoriesRepositoryInterface;
use Litecms\BusCategory\Models\BusCategories;

/**
 * Resource controller class for bus_categories.
 */
class BusCategoriesResourceController extends BaseController
{

    /**
     * Initialize bus_categories resource controller.
     *
     * @param type BusCategoriesRepositoryInterface $bus_categories
     *
     * @return null
     */
    public function __construct(BusCategoriesRepositoryInterface $bus_categories)
    {
        parent::__construct();
        $this->repository = $bus_categories;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\BusCategory\Repositories\Criteria\BusCategoriesResourceCriteria::class);
    }

    /**
     * Display a list of bus_categories.
     *
     * @return Response
     */
    public function index(BusCategoriesRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\BusCategory\Repositories\Presenter\BusCategoriesPresenter::class)
                ->$function();
        }

        $bus_categories = $this->repository->paginate();

        return $this->response->title(trans('bus_category::bus_categories.names'))
            ->view('bus_category::bus_categories.index', true)
            ->data(compact('bus_categories'))
            ->output();
    }

    /**
     * Display bus_categories.
     *
     * @param Request $request
     * @param Model   $bus_categories
     *
     * @return Response
     */
    public function show(BusCategoriesRequest $request, BusCategories $bus_categories)
    {

        if ($bus_categories->exists) {
            $view = 'bus_category::bus_categories.show';
        } else {
            $view = 'bus_category::bus_categories.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('bus_category::bus_categories.name'))
            ->data(compact('bus_categories'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new bus_categories.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BusCategoriesRequest $request)
    {

        $bus_categories = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('bus_category::bus_categories.name')) 
            ->view('bus_category::bus_categories.create', true) 
            ->data(compact('bus_categories'))
            ->output();
    }

    /**
     * Create new bus_categories.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BusCategoriesRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $bus_categories                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('bus_category::bus_categories.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('bus_category/bus_categories/' . $bus_categories->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/bus_category/bus_categories'))
                ->redirect();
        }

    }

    /**
     * Show bus_categories for editing.
     *
     * @param Request $request
     * @param Model   $bus_categories
     *
     * @return Response
     */
    public function edit(BusCategoriesRequest $request, BusCategories $bus_categories)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('bus_category::bus_categories.name'))
            ->view('bus_category::bus_categories.edit', true)
            ->data(compact('bus_categories'))
            ->output();
    }

    /**
     * Update the bus_categories.
     *
     * @param Request $request
     * @param Model   $bus_categories
     *
     * @return Response
     */
    public function update(BusCategoriesRequest $request, BusCategories $bus_categories)
    {
        try {
            $attributes = $request->all();

            $bus_categories->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('bus_category::bus_categories.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('bus_category/bus_categories/' . $bus_categories->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('bus_category/bus_categories/' . $bus_categories->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the bus_categories.
     *
     * @param Model   $bus_categories
     *
     * @return Response
     */
    public function destroy(BusCategoriesRequest $request, BusCategories $bus_categories)
    {
        try {

            $bus_categories->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('bus_category::bus_categories.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('bus_category/bus_categories/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('bus_category/bus_categories/' . $bus_categories->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple bus_categories.
     *
     * @param Model   $bus_categories
     *
     * @return Response
     */
    public function delete(BusCategoriesRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('bus_category::bus_categories.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('bus_category/bus_categories'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/bus_category/bus_categories'))
                ->redirect();
        }

    }

    /**
     * Restore deleted bus_categories.
     *
     * @param Model   $bus_categories
     *
     * @return Response
     */
    public function restore(BusCategoriesRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('bus_category::bus_categories.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/bus_category/bus_categories'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/bus_category/bus_categories/'))
                ->redirect();
        }

    }

}
